# vue3-puzzle-vcode 滑动验证


&lt;!--more--&gt;


## 安装  

``` Markdown {data-open=true}
npm install vue3-puzzle-vcode --save
yarn add vue3-puzzle-vcode
```

## 注册为全局组件

``` js {data-open=true,linenos=table,hl_lines=[10,14],linenostart=1}
import { createApp } from &#39;vue&#39;
import App from &#39;./App.vue&#39;
import router from &#39;./router&#39;
import &#39;@/assets/css/style.css&#39;
import &#39;@/assets/iconfont/iconfont.css&#39;
import &#39;element-plus/es/components/message/style/css&#39;
import &#39;element-plus/es/components/message-box/style/css&#39;
import &#39;element-plus/theme-chalk/el-message.css&#39;
import &#39;element-plus/theme-chalk/el-message-box.css&#39;
import Vcode from &#34;vue3-puzzle-vcode&#34;;

createApp(App)
    .use(router)
    .component(&#39;Vcode&#39;, Vcode)
    .mount(&#39;#app&#39;)
```


## 引入组件

``` html  {data-open=true,linenos=table,hl_lines=[6,10],linenostart=1}
&lt;script&gt;
import { ref, reactive } from &#39;vue&#39;;
import { landRelevant } from &#34;@/api/api.js&#34;;
import { ElMessage } from &#34;element-plus&#34;;
import { useRouter } from &#39;vue-router&#39;
import Vcode from &#34;vue3-puzzle-vcode&#34;;
export default {
  setup() {

    return {
      // 其他数据
      Vcode,
    };
  }
}
&lt;/script&gt;
```


## 使用

``` html {data-open=true}
&lt;template&gt;
  &lt;Vcode :show=&#34;isShow&#34; @success=&#34;onSuccess&#34; @close=&#34;onClose&#34; :imgs=&#34;[Img1, Img2]&#34;/&gt;
  &lt;button @click=&#34;onShow&#34;&gt;开始验证&lt;/button&gt;
&lt;/template&gt;
&lt;script&gt;
import { ref } from &#34;vue&#34;;
import Vcode from &#34;vue3-puzzle-vcode&#34;;
export default {
  setup() {
    const isShow = ref(false);// 验证码模态框是否出现
    const Img1 = ref(&#39;https://img0.baidu.com/it/u=3422287847,344441285&amp;fm=253&amp;app=138&amp;size=w931&amp;n=0&amp;f=JPEG&amp;fmt=auto?sec=1725642000&amp;t=59fe0eb1400ff433acaf83993ea0ada4&#39;);
    const Img2 = ref(&#39;https://img2.baidu.com/it/u=1544882228,2394903552&amp;fm=253&amp;app=138&amp;size=w931&amp;n=0&amp;f=JPEG&amp;fmt=auto?sec=1725642000&amp;t=8d7d4a0dc42e691db4c3dc25941a151c&#39;);
    
    const onShow = () =&gt; {
      isShow.value = true;
    };
    
    const onClose = () =&gt; {
      isShow.value = false;  
    };
    
    const onSuccess = () =&gt; {
      onClose(); // 验证成功，手动关闭模态框
    };
  }
}
&lt;/script&gt;
```

### 使用网络图片

``` html {data-open=true}
&lt;template&gt;
  &lt;Vcode :show=&#34;isShow&#34; @success=&#34;onSuccess&#34; @close=&#34;onClose&#34; :imgs=&#34;images&#34;/&gt;
&lt;/template&gt;
&lt;script&gt;
export default {
  setup() {
    const images = ref([
      &#39;https://img0.baidu.com/it/u=3422287847,344441285&amp;fm=253&amp;app=138&amp;size=w931&amp;n=0&amp;f=JPEG&amp;fmt=auto?sec=1725642000&amp; t=59fe0eb1400ff433acaf83993ea0ada4&#39;,
      &#39;https://img2.baidu.com/it/u=1544882228,2394903552&amp;fm=253&amp;app=138&amp;size=w931&amp;n=0&amp;f=JPEG&amp;fmt=auto?sec=1725642000&amp;  t=8d7d4a0dc42e691db4c3dc25941a151c&#39;,
    ])
  }
}
&lt;/script&gt;
```

### 使用项目图片

``` html {data-open=true}
&lt;template&gt;
  &lt;Vcode :show=&#34;isShow&#34; @success=&#34;onSuccess&#34; @close=&#34;onClose&#34; :imgs=&#34;images&#34;/&gt;
&lt;/template&gt;
&lt;script&gt;
import img1 from &#34;../assets/images/puzzle01.jpg&#34;;
import img2 from &#34;../assets/images/puzzle02.jpg&#34;;
import img3 from &#34;../assets/images/puzzle03.jpg&#34;;
export default {
  setup() {
    const images = ref([
      img1,
      img2,
      img3,
    ])
  }
}
&lt;/script&gt;
```

## 参数


| 字段 | 类型 | 默认值 | 说明 |
| :----: | :----: | :----: | :----: |
| show | Boolean | false | 是否显示验证码弹框 |
| type | String | &#34;modal&#34; | &#34;modal&#34;模态框形式 / &#34;inside&#34;内嵌形式 |
| canvasWidth |	Number | 310 | 主图区域的宽度，单位 px |
| canvasHeight | Number | 160 | 主图区域的高度，单位 px |
| puzzleScale |	Number | 1 | 拼图块(小的拼图)的大小比例，0.2 ～ 2 ，数字越大，拼图越大 |
| sliderSize | Number | 50 | 左下角用户拖动的那个滑块的尺寸，单位 px |
| range |	Number | 10 | 判断成功的误差范围，单位 px, 滑动的距离和拼图的距离小于等于此值时，会判定重合 |
| imgs | Array | null | 自定义图片 |
| successText |	String | &#34;验证通过！&#34;	| 验证成功时的提示文字 |
| failText | String | &#34;验证失败，请重试&#34; | 验证失败时的提示文字 |
| sliderText | String | &#34;拖动滑块完成拼图&#34; | 下方滑动条里的文字 |
| className | String | &#34;&#34; | 给根元素一个class类用于自定义样式 |
| zIndex | Number | 999 | 设置根元素一个层级z-index |


## 事件

| 事件名 | 返回值 | 说明 |
| :----: | :----: | :----: |	
| success | 偏差值 | 验证通过时会触发，返回值是用户移动的距离跟目标距离的偏差值 px |
| fail | 偏差值 | 验证失败时会触发，返回值同上 |
| close | null | 用户点击遮罩层的回调 |
| reset	| null | 用户手动点击右上角刷新按钮时触发的回调 |



## 内嵌形式
入参 `type=&#34;inside&#34;`，将启用内嵌模式，应该用一个元素包裹 &lt;Vcode /&gt;：  

``` html {data-open=true}
&lt;template&gt;
  &lt;div class=&#34;box&#34;&gt;
    &lt;Vcode type=&#34;inside&#34; :show=&#34;isShow&#34; /&gt;
  &lt;/div&gt;
&lt;/template&gt;

&lt;style&gt;
  .box{
    position: relative;
    width: 320px;
    height: auto;
  }
&lt;/style&gt;
```


---
{.awesome-hr}


---

> 作者: [piliqiu](https://piliqiu.com/)  
> URL: https://piliqiu.com/posts/e86d243/  

